import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

import aws_cdk._jsii
import constructs._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "@renovosolutions/cdk-library-one-time-event",
    "2.0.20",
    __name__[0:-6],
    "cdk-library-one-time-event@2.0.20.jsii.tgz",
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
